import http from "@/utils/request";
import type { Result } from "@/types/data";
import type { ContractListParams, ContractListResult, SignBatchParams, ExtReqResult, TemplateStatusParams, TemplateContentParams, TemplateContentResult, TemplateConfirmParams, SendCaptchaParams, VerifyCaptchaParams } from "@/types/home";

export const homeApi = {
  /**
   * 获取签署文件列表
   * @param data
   * @returns ContractListResult
   */
  getContractFile: (data: ContractListParams) => http.post<ContractListResult[]>('/auth/signgateway/sign/querySignData', data),

  /**
   * 提交批量签署合同
   * @param data 
   * @returns ExtReqResult or any
   */
  postBatchSign: (data: SignBatchParams) => http.post<Result<ExtReqResult>[]>('/auth/signgateway/sign/hdb/batchSignContract', data),

  /**
   * 协议签署状态
   * @param data 
   * @returns boolean
   */
  getTemplateStatus: (data: TemplateStatusParams) => http.post<boolean>('/basic/m/new/validate/sign', data),

  /**
   * 协议内容
   * @param data 
   * @returns TemplateContentResult
   */
  getTemplateContent: (params: TemplateContentParams) => http.get<TemplateContentResult>('/basic/n/find/agre/type', {params}),
  
  /**
   * 确认协议
   * @param data
   * @returns boolean
   */
  postTemplateConfirm: (data:TemplateConfirmParams) => http.post<boolean>('/basic/m/sign/agrt', data),

  /**
   * 获取登录人手机号
   * @param data
   * @returns boolean
   */
  getPhoneCode: () => http.get<string>('/auth/getInfoBeforeSendSms'),

  /**
   * 发送验证码
   * @param data
   * @return null
   */
  getCaptcha: (data: SendCaptchaParams) => http.post<null>('/auth/sendVerificationMessageSms', data),
  
  /**
   * 短信验证码验证结果
   * @param data
   * @returns boolean
   */
  postVerifyCaptcha: (data: VerifyCaptchaParams) => http.post<null>('/auth/submitVerifyMessageCode', data),
}
